import os
from setuptools import setup

setup(
    name = "rubbrband",
    version = "0.1.0",
    author = "Rubbrband Inc",
    author_email = "contact@rubbrband.com",
    description = "A library to train ML models.",
    long_description="A library to train ML models",
    license = "BSD",
    keywords = "rubbrband ml-models ml",
    packages=['rubbrband'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
)